@@ -1,7 +1,7 @@
 /****************************************************************************************
 **
+** Copyright (c) 2022 Open Mobile Platform LLC.
 ** Copyright (C) 2017 Jolla Ltd.
-** Contact: Raine Makelainen <raine.makelainen@jolla.com>
 ** All rights reserved.
 **
 *****************************************************************************************/
@@ -44,6 +44,8 @@ class Q_DECL_EXPORT AccessPolicy : public QObject
     Q_PROPERTY(bool accountCreationEnabled READ accountCreationEnabled NOTIFY accountCreationEnabledChanged)
     Q_PROPERTY(bool voiceCallEnabled READ voiceCallEnabled NOTIFY voiceCallEnabledChanged)
     Q_PROPERTY(bool smsEnabled READ smsEnabled NOTIFY smsEnabledChanged)
+    Q_PROPERTY(bool sdMountEnabled READ sdMountEnabled NOTIFY sdMountEnabledChanged)
+    Q_PROPERTY(bool usbMountEnabled READ usbMountEnabled NOTIFY usbMountEnabledChanged)
 
 public:
     AccessPolicy(QObject *parent = 0);
@@ -121,6 +123,11 @@ public:
     bool accountCreationEnabled() const;
     bool setAccountCreationEnabled(bool enabled);
 
+    bool sdMountEnabled() const;
+    bool setSdMountEnabled(bool enabled);
+
+    bool usbMountEnabled() const;
+    bool setUsbMountEnabled(bool enabled);
 
     bool voiceCallEnabled() const;
     bool setVoiceCallEnabled(bool enabled);
@@ -158,6 +165,8 @@ signals:
     void accountCreationEnabledChanged();
     void voiceCallEnabledChanged();
     void smsEnabledChanged();
+    void sdMountEnabledChanged();
+    void usbMountEnabledChanged();
 
 private:
     AccessPolicyPrivate *d_ptr;
